com.blockether.spel.constants

Clojure vars wrapping Playwright enum values as flat, documented names.

Eliminates the need for Java enum interop in --eval mode. Flat naming: constants/<category>-<value>.

Usage: (require '[com.blockether.spel.constants :as constants]) (page/wait-for-load-state pg constants/load-state-networkidle) (page/navigate pg url {:wait-until constants/wait-until-commit})

Clojure vars wrapping Playwright enum values as flat, documented names.

Eliminates the need for Java enum interop in --eval mode.
Flat naming: `constants/<category>-<value>`.

Usage:
  (require '[com.blockether.spel.constants :as constants])
  (page/wait-for-load-state pg constants/load-state-networkidle)
  (page/navigate pg url {:wait-until constants/wait-until-commit})
raw docstring

color-scheme-darkclj

source

color-scheme-lightclj

source

color-scheme-no-preferenceclj

source

forced-colors-activeclj

source

forced-colors-noneclj

source

load-state-domcontentloadedclj

source

load-state-loadclj

source

load-state-networkidleclj

source

media-printclj

source

media-screenclj

source

mouse-button-leftclj

source

mouse-button-middleclj

source

mouse-button-rightclj

source

reduced-motion-no-preferenceclj

source

reduced-motion-reduceclj

source

screenshot-type-jpegclj

source

screenshot-type-pngclj

source

selector-state-attachedclj

source

selector-state-detachedclj

source

selector-state-hiddenclj

source

selector-state-visibleclj

source

wait-until-commitclj

source

wait-until-domcontentloadedclj

source

wait-until-loadclj

source

wait-until-networkidleclj

source

cljdoc builds & hosts documentation for Clojure/Script libraries