Convert HTML documents into readable Markdown using the browser runtime.
Convert HTML documents into readable Markdown using the browser runtime.
(html->markdown pg html)(html->markdown pg
html
{:keys [title? readable? a11y?]
:or {title? true readable? true a11y? true}})Converts an HTML string into Markdown using an existing Playwright page.
Options:
Converts an HTML string into Markdown using an existing Playwright page. Options: - :title? include document title as a top-level heading (default true) - :readable? prefer main content over full page chrome (default true) - :a11y? use accessibility-based extraction when HTML is the current page content (default true)
(page->markdown pg)(page->markdown pg {:keys [title?] :or {title? true}})Converts the current page into Markdown using the accessibility snapshot.
Options:
Converts the current page into Markdown using the accessibility snapshot. Options: - :title? include document title as a top-level heading (default true)
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |