Clojure only.

com.blockether.spel.markdownify

Convert HTML documents into readable Markdown using the browser runtime.

Convert HTML documents into readable Markdown using the browser runtime.
raw docstring

html->markdownclj

(html->markdown pg html)
(html->markdown pg
                html
                {:keys [title? readable?] :or {title? true readable? true}})

Converts an HTML string into Markdown using an existing Playwright page.

Options:

  • :title? include document title as a top-level heading (default true)
  • :readable? prefer main content over full page chrome (default true)
Converts an HTML string into Markdown using an existing Playwright page.

Options:
- :title? include document title as a top-level heading (default true)
- :readable? prefer main content over full page chrome (default true)
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries