Convert HTML documents into readable Markdown using the browser runtime.
Convert HTML documents into readable Markdown using the browser runtime.
(html->markdown pg html)(html->markdown pg
html
{:keys [title? readable?] :or {title? true readable? true}})Converts an HTML string into Markdown using an existing Playwright page.
Options:
Converts an HTML string into Markdown using an existing Playwright page. Options: - :title? include document title as a top-level heading (default true) - :readable? prefer main content over full page chrome (default true)
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |